OC.L10N.register(
    "lib",
    {
    "Help" : "幫助",
    "Personal" : "個人",
    "Users" : "用戶",
    "Admin" : "管理",
    "Recommended" : "建議",
    "today" : "今日",
    "yesterday" : "昨日",
    "last month" : "前一月",
    "_%n month ago_::_%n months ago_" : ["%n 月前"],
    "last year" : "上年",
    "_%n hour ago_::_%n hours ago_" : ["%n 小時前"],
    "_%n minute ago_::_%n minutes ago_" : ["%n 分鐘前"],
    "seconds ago" : "秒前",
    "Apps" : "軟件"
},
"nplurals=1; plural=0;");
